import matplotlib.pyplot as plt
import numpy as np
from scipy.integrate import odeint

def calc_rate(P=0, d=0.0001, B=0.0095, G=0.0001, A=0.0001, S0=500):
    def f(y, t):
        Si = y[0]
        Zi = y[1]
        Ri = y[2]
        # the model equations (see Munz et al. 2009)
        f0 = P - B*Si*Zi - d*Si
        f1 = B*Si*Zi + G*Ri - A*Si*Zi
        f2 = d*Si + A*Si*Zi - G*Ri
        return [f0, f1, f2]
    Z0 = 0                  # initial zombie population
    R0 = 0                  # initial death population
    y0 = [S0, Z0, R0]       # initial condition vector
    t  = np.linspace(0, 5., 1000)   # time grid
    # solve the DEs
    soln = odeint(f, y0, t)
    S = soln[:, 0]
    Z = soln[:, 1]
    R = soln[:, 2]            
    return t, S, Z

def plot_zombie_rate(P=0, d=0.0001, B=0.0095, G=0.0001, A=0.0001, S0=500):
    '''Plot growth rate for a specific city.'''
    t, S, Z = calc_rate(P=P, d=d, B=B, G=G, A=A, S0=S0)
    plt.figure()
    plt.plot(t, S, label='Living')
    plt.plot(t, Z, label='Zombies')
    plt.xlabel('Days from outbreak')
    plt.ylabel('Population')
    plt.title('Zombie Apocalypse')
    plt.legend(loc=0)
    return plt.gcf()

if __name__ == "__main__":
    plot_zombie_rate()
    plt.show()
